import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'login.m.dart';

class LoginService extends JsonRpcClientBase {
	LoginService(
		String host, {
		String serviceName = "ILoginService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => UserSessionInfo.fromJson(map));
	}

	Future<UserSessionInfo> clientLoginAsync(UserLoginInfo userLoginInfo) async {
		var rpcRst = await call("ClientLoginAsync", userLoginInfo);
		var result = UserSessionInfo.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<UserSessionInfo> commonLoginAsync(String anyAccount,String anyCode,String password) async {
		var rpcRst = await call("CommonLoginAsync", [anyAccount,anyCode,password]);
		var result = UserSessionInfo.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<int> checkLoginType(String anyAccount) async {
		var rpcRst = await call("CheckLoginType", anyAccount);
		return rpcRst;
	}

	Future<bool> commonSignUpAsync(String anyAccount,String anyCode,String password) async {
		var rpcRst = await call("CommonSignUpAsync", [anyAccount,anyCode,password]);
		return rpcRst;
	}

	Future<bool> signUpAsync(UserInfo userInfo) async {
		var rpcRst = await call("SignUpAsync", userInfo);
		return rpcRst;
	}

	Future<bool> checkSMSVerificationCode(String userPhone,String verifyCode) async {
		var rpcRst = await call("CheckSMSVerificationCode", [userPhone,verifyCode]);
		return rpcRst;
	}

	Future<bool> sendSMSVerificationCode(String userPhone) async {
		var rpcRst = await call("SendSMSVerificationCode", userPhone);
		return rpcRst;
	}

	Future<bool> sendEmailVerificationCode(String emailAddress) async {
		var rpcRst = await call("SendEmailVerificationCode", emailAddress);
		return rpcRst;
	}

	Future<bool> checkEmailVerificationCode(String emailAddress,String verifyCode) async {
		var rpcRst = await call("CheckEmailVerificationCode", [emailAddress,verifyCode]);
		return rpcRst;
	}

	Future<bool> retrievePasswordByPhone(String phone,String verifyCode,String newPassword) async {
		var rpcRst = await call("RetrievePasswordByPhone", [phone,verifyCode,newPassword]);
		return rpcRst;
	}

	Future<bool> retrievePasswordByEmail(String mail,String verifyCode,String newPassword) async {
		var rpcRst = await call("RetrievePasswordByEmail", [mail,verifyCode,newPassword]);
		return rpcRst;
	}

}

