class UserSessionInfo {
	String? userCode;
	String? deviceId;
	String? sessionId;

	UserSessionInfo({
		this.userCode,
		this.deviceId,
		this.sessionId,
	});

	factory UserSessionInfo.fromJson(Map<String, dynamic> map) {
		return UserSessionInfo( 
			userCode: map['UserCode'],
			deviceId: map['DeviceId'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(userCode != null)
			map['UserCode'] = userCode;
		if(deviceId != null)
			map['DeviceId'] = deviceId;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

enum EnumLoginProcessorType {
	Official,
	Wechat,
	Phone,
	Email,
	Unregistered,
}

class LoginProcessorInfo {
	String? userName;
	String? password;
	String? phone;
	String? email;
	String? verifyCode;
	String? wechatToken;

	LoginProcessorInfo({
		this.userName,
		this.password,
		this.phone,
		this.email,
		this.verifyCode,
		this.wechatToken,
	});

	factory LoginProcessorInfo.fromJson(Map<String, dynamic> map) {
		return LoginProcessorInfo( 
			userName: map['UserName'],
			password: map['Password'],
			phone: map['Phone'],
			email: map['Email'],
			verifyCode: map['VerifyCode'],
			wechatToken: map['WechatToken'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(userName != null)
			map['UserName'] = userName;
		if(password != null)
			map['Password'] = password;
		if(phone != null)
			map['Phone'] = phone;
		if(email != null)
			map['Email'] = email;
		if(verifyCode != null)
			map['VerifyCode'] = verifyCode;
		if(wechatToken != null)
			map['WechatToken'] = wechatToken;
		return map;
	}
}

class ClientInfo {
	String? clientIpAndPort;
	String? clientDeviceId;
	String? clientSource;
	String? clientExtensionInfo;

	ClientInfo({
		this.clientIpAndPort,
		this.clientDeviceId,
		this.clientSource,
		this.clientExtensionInfo,
	});

	factory ClientInfo.fromJson(Map<String, dynamic> map) {
		return ClientInfo( 
			clientIpAndPort: map['ClientIpAndPort'],
			clientDeviceId: map['ClientDeviceId'],
			clientSource: map['ClientSource'],
			clientExtensionInfo: map['ClientExtensionInfo'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(clientIpAndPort != null)
			map['ClientIpAndPort'] = clientIpAndPort;
		if(clientDeviceId != null)
			map['ClientDeviceId'] = clientDeviceId;
		if(clientSource != null)
			map['ClientSource'] = clientSource;
		if(clientExtensionInfo != null)
			map['ClientExtensionInfo'] = clientExtensionInfo;
		return map;
	}
}

class UserLoginInfo {
	EnumLoginProcessorType loginType;
	LoginProcessorInfo? processorInfo;
	ClientInfo? clientInfo;

	UserLoginInfo({
		this.loginType=EnumLoginProcessorType.Official,
		this.processorInfo,
		this.clientInfo,
	});

	factory UserLoginInfo.fromJson(Map<String, dynamic> map) {
		return UserLoginInfo( 
			loginType: EnumLoginProcessorType.values.firstWhere((e) => e.index == map['LoginType']),
			processorInfo: map['ProcessorInfo'],
			clientInfo: map['ClientInfo'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['LoginType'] = loginType.index;
		if(processorInfo != null)
			map['ProcessorInfo'] = processorInfo;
		if(clientInfo != null)
			map['ClientInfo'] = clientInfo;
		return map;
	}
}

enum UserInfoStateEnum {
	Nonactivated,
	Activated,
}

class UserInfo {
	String? userCode;
	String? userName;
	String? phone;
	String? email;
	String? nickName;
	String? fullName;
	String? headImageToken;
	String? organizationCode;
	List<String>? authorityGroups;
	List<String>? bindDevices;
	int score;
	String? lastIP;
	UserInfoStateEnum userState;
	String? securityQuestion;
	String? securityAnswers;
	DateTime? createTime;
	DateTime? updateTime;

	UserInfo({
		this.userCode,
		this.userName,
		this.phone,
		this.email,
		this.nickName,
		this.fullName,
		this.headImageToken,
		this.organizationCode,
		this.authorityGroups,
		this.bindDevices,
		this.score=0,
		this.lastIP,
		this.userState=UserInfoStateEnum.Nonactivated,
		this.securityQuestion,
		this.securityAnswers,
		this.createTime,
		this.updateTime,
	});

	factory UserInfo.fromJson(Map<String, dynamic> map) {
		return UserInfo( 
			userCode: map['UserCode'],
			userName: map['UserName'],
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			headImageToken: map['HeadImageToken'],
			organizationCode: map['OrganizationCode'],
			authorityGroups: map['AuthorityGroups'].cast<String>().toList(),
			bindDevices: map['BindDevices'].cast<String>().toList(),
			score: map['Score'],
			lastIP: map['LastIP'],
			userState: UserInfoStateEnum.values.firstWhere((e) => e.index == map['UserState']),
			securityQuestion: map['SecurityQuestion'],
			securityAnswers: map['SecurityAnswers'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(userCode != null)
			map['UserCode'] = userCode;
		if(userName != null)
			map['UserName'] = userName;
		if(phone != null)
			map['Phone'] = phone;
		if(email != null)
			map['Email'] = email;
		if(nickName != null)
			map['NickName'] = nickName;
		if(fullName != null)
			map['FullName'] = fullName;
		if(headImageToken != null)
			map['HeadImageToken'] = headImageToken;
		if(organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if(authorityGroups != null)
			map['AuthorityGroups'] = authorityGroups;
		if(bindDevices != null)
			map['BindDevices'] = bindDevices;
		map['Score'] = score;
		if(lastIP != null)
			map['LastIP'] = lastIP;
		map['UserState'] = userState.index;
		if(securityQuestion != null)
			map['SecurityQuestion'] = securityQuestion;
		if(securityAnswers != null)
			map['SecurityAnswers'] = securityAnswers;
		if(createTime != null)
			map['CreateTime'] = createTime;
		if(updateTime != null)
			map['UpdateTime'] = updateTime;
		return map;
	}
}


