import 'package:fis_common/json_convert.dart';

enum GenderTypeEnum {
	Male,
	Female,
}

enum PatientTypeEnum {
	Default,
}

class PatientInfo {
	String? patientCode;
	String? firstName;
	String? lastName;
	String? patientCardNo;
	DateTime? birthday;
	GenderTypeEnum genderType;
	String? patientCaseHistory;
	String? patientPhone;
	PatientTypeEnum patientType;
	DateTime? createTime;
	DateTime? updateTime;

	PatientInfo({
		this.patientCode,
		this.firstName,
		this.lastName,
		this.patientCardNo,
		this.birthday,
		this.genderType=GenderTypeEnum.Male,
		this.patientCaseHistory,
		this.patientPhone,
		this.patientType=PatientTypeEnum.Default,
		this.createTime,
		this.updateTime,
	});

	factory PatientInfo.fromJson(Map<String, dynamic> map) {
		return PatientInfo( 
			patientCode: map['PatientCode'],
			firstName: map['FirstName'],
			lastName: map['LastName'],
			patientCardNo: map['PatientCardNo'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			genderType: GenderTypeEnum.values.firstWhere((e) => e.index == map['GenderType']),
			patientCaseHistory: map['PatientCaseHistory'],
			patientPhone: map['PatientPhone'],
			patientType: PatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(patientCode != null)
			map['PatientCode'] = patientCode;
		if(firstName != null)
			map['FirstName'] = firstName;
		if(lastName != null)
			map['LastName'] = lastName;
		if(patientCardNo != null)
			map['PatientCardNo'] = patientCardNo;
		if(birthday != null)
			map['Birthday'] = birthday;
		map['GenderType'] = genderType.index;
		if(patientCaseHistory != null)
			map['PatientCaseHistory'] = patientCaseHistory;
		if(patientPhone != null)
			map['PatientPhone'] = patientPhone;
		map['PatientType'] = patientType.index;
		if(createTime != null)
			map['CreateTime'] = createTime;
		if(updateTime != null)
			map['UpdateTime'] = updateTime;
		return map;
	}
}

class CreatePatientInfoRequest {
	PatientInfo? info;
	String? sessionId;

	CreatePatientInfoRequest({
		this.info,
		this.sessionId,
	});

	factory CreatePatientInfoRequest.fromJson(Map<String, dynamic> map) {
		return CreatePatientInfoRequest( 
			info: map['Info'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(info != null)
			map['Info'] = info;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

enum DeviceDataTypeEnum {
	Default,
}

class DeviceData {
	String? deviceDataCode;
	String? deviceCode;
	String? deviceFileCode;
	String? recordCode;
	String? patientCode;
	String? previewImageToken;
	String? dataToken;
	DeviceDataTypeEnum deviceDataType;
	String? processResult;
	DateTime? createTime;
	DateTime? updateTime;

	DeviceData({
		this.deviceDataCode,
		this.deviceCode,
		this.deviceFileCode,
		this.recordCode,
		this.patientCode,
		this.previewImageToken,
		this.dataToken,
		this.deviceDataType=DeviceDataTypeEnum.Default,
		this.processResult,
		this.createTime,
		this.updateTime,
	});

	factory DeviceData.fromJson(Map<String, dynamic> map) {
		return DeviceData( 
			deviceDataCode: map['DeviceDataCode'],
			deviceCode: map['DeviceCode'],
			deviceFileCode: map['DeviceFileCode'],
			recordCode: map['RecordCode'],
			patientCode: map['PatientCode'],
			previewImageToken: map['PreviewImageToken'],
			dataToken: map['DataToken'],
			deviceDataType: DeviceDataTypeEnum.values.firstWhere((e) => e.index == map['DeviceDataType']),
			processResult: map['ProcessResult'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(deviceDataCode != null)
			map['DeviceDataCode'] = deviceDataCode;
		if(deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if(deviceFileCode != null)
			map['DeviceFileCode'] = deviceFileCode;
		if(recordCode != null)
			map['RecordCode'] = recordCode;
		if(patientCode != null)
			map['PatientCode'] = patientCode;
		if(previewImageToken != null)
			map['PreviewImageToken'] = previewImageToken;
		if(dataToken != null)
			map['DataToken'] = dataToken;
		map['DeviceDataType'] = deviceDataType.index;
		if(processResult != null)
			map['ProcessResult'] = processResult;
		if(createTime != null)
			map['CreateTime'] = createTime;
		if(updateTime != null)
			map['UpdateTime'] = updateTime;
		return map;
	}
}

class CreateDeviceDataRequest {
	DeviceData? info;
	String? sessionId;

	CreateDeviceDataRequest({
		this.info,
		this.sessionId,
	});

	factory CreateDeviceDataRequest.fromJson(Map<String, dynamic> map) {
		return CreateDeviceDataRequest( 
			info: map['Info'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(info != null)
			map['Info'] = info;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

enum RecordTypeEnum {
	Ultrasound,
	Electrocardio,
}

enum CheckTypeEnum {
	Default,
}

enum RecordStatusEnum {
	Default,
}

class RecordInfo {
	String? recordCode;
	String? patientCode;
	String? patientName;
	String? orgName;
	RecordTypeEnum recordType;
	CheckTypeEnum checkType;
	String? localRecordCode;
	RecordStatusEnum recordStatus;
	String? recordRemark;
	String? tags;
	DateTime? createTime;
	DateTime? updateTime;

	RecordInfo({
		this.recordCode,
		this.patientCode,
		this.patientName,
		this.orgName,
		this.recordType=RecordTypeEnum.Ultrasound,
		this.checkType=CheckTypeEnum.Default,
		this.localRecordCode,
		this.recordStatus=RecordStatusEnum.Default,
		this.recordRemark,
		this.tags,
		this.createTime,
		this.updateTime,
	});

	factory RecordInfo.fromJson(Map<String, dynamic> map) {
		return RecordInfo( 
			recordCode: map['RecordCode'],
			patientCode: map['PatientCode'],
			patientName: map['PatientName'],
			orgName: map['OrgName'],
			recordType: RecordTypeEnum.values.firstWhere((e) => e.index == map['RecordType']),
			checkType: CheckTypeEnum.values.firstWhere((e) => e.index == map['CheckType']),
			localRecordCode: map['LocalRecordCode'],
			recordStatus: RecordStatusEnum.values.firstWhere((e) => e.index == map['RecordStatus']),
			recordRemark: map['RecordRemark'],
			tags: map['Tags'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(recordCode != null)
			map['RecordCode'] = recordCode;
		if(patientCode != null)
			map['PatientCode'] = patientCode;
		if(patientName != null)
			map['PatientName'] = patientName;
		if(orgName != null)
			map['OrgName'] = orgName;
		map['RecordType'] = recordType.index;
		map['CheckType'] = checkType.index;
		if(localRecordCode != null)
			map['LocalRecordCode'] = localRecordCode;
		map['RecordStatus'] = recordStatus.index;
		if(recordRemark != null)
			map['RecordRemark'] = recordRemark;
		if(tags != null)
			map['Tags'] = tags;
		if(createTime != null)
			map['CreateTime'] = createTime;
		if(updateTime != null)
			map['UpdateTime'] = updateTime;
		return map;
	}
}

class CreateRecordInfoRequest {
	RecordInfo? info;
	String? sessionId;

	CreateRecordInfoRequest({
		this.info,
		this.sessionId,
	});

	factory CreateRecordInfoRequest.fromJson(Map<String, dynamic> map) {
		return CreateRecordInfoRequest( 
			info: map['Info'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(info != null)
			map['Info'] = info;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

class GetDeviceDataDetailRequest {
	String? deviceDataCode;
	String? sessionId;

	GetDeviceDataDetailRequest({
		this.deviceDataCode,
		this.sessionId,
	});

	factory GetDeviceDataDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceDataDetailRequest( 
			deviceDataCode: map['DeviceDataCode'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(deviceDataCode != null)
			map['DeviceDataCode'] = deviceDataCode;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

class GetRecordInfoDetailRequest {
	String? recordCode;
	String? sessionId;

	GetRecordInfoDetailRequest({
		this.recordCode,
		this.sessionId,
	});

	factory GetRecordInfoDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetRecordInfoDetailRequest( 
			recordCode: map['RecordCode'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(recordCode != null)
			map['RecordCode'] = recordCode;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

class PageCollection<T> {
	int currentPage;
	int pageSize;
	int dataCount;
	List<T>? pageData;

	PageCollection({
		this.currentPage=0,
		this.pageSize=0,
		this.dataCount=0,
		this.pageData,
	});

	factory PageCollection.fromJson(Map<String, dynamic> map) {
		List<T> pageDataList = [];
		if (map['PageData'] != null) {
			pageDataList.addAll(
					(map['PageData'] as List).map((e) => FJsonConvert.fromJson<T>(e)!));
		}
		return PageCollection( 
			currentPage: map['CurrentPage'],
			pageSize: map['PageSize'],
			dataCount: map['DataCount'],
			pageData: pageDataList,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['CurrentPage'] = currentPage;
		map['PageSize'] = pageSize;
		map['DataCount'] = dataCount;
		if(pageData != null)
			map['PageData'] = pageData;
		return map;
	}
}

class PageRequest {
	int currentPage;
	int pageSize;
	Map<String,String>? filter;
	bool isFuzzy;
	String? sessionId;

	PageRequest({
		this.currentPage=0,
		this.pageSize=0,
		this.filter,
		this.isFuzzy=false,
		this.sessionId,
	});

	factory PageRequest.fromJson(Map<String, dynamic> map) {
		return PageRequest( 
			currentPage: map['CurrentPage'],
			pageSize: map['PageSize'],
			filter: map['Filter'].cast<String,String>(),
			isFuzzy: map['IsFuzzy'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['CurrentPage'] = currentPage;
		map['PageSize'] = pageSize;
		if(filter != null)
			map['Filter'] = filter;
		map['IsFuzzy'] = isFuzzy;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}

class GetPatientInfoRequest {
	String? patientCode;
	String? sessionId;

	GetPatientInfoRequest({
		this.patientCode,
		this.sessionId,
	});

	factory GetPatientInfoRequest.fromJson(Map<String, dynamic> map) {
		return GetPatientInfoRequest( 
			patientCode: map['PatientCode'],
			sessionId: map['SessionId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(patientCode != null)
			map['PatientCode'] = patientCode;
		if(sessionId != null)
			map['SessionId'] = sessionId;
		return map;
	}
}


